@@ -9,7 +9,7 @@
 #
 package Reindeer::Role;
 {
-  $Reindeer::Role::VERSION = '0.004';
+  $Reindeer::Role::VERSION = '0.005';
 }
 
 # ABSTRACT: Reindeer in role form
@@ -48,13 +48,15 @@ sub init_meta {
 
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
 Reindeer::Role - Reindeer in role form
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -66,9 +68,37 @@ version 0.004
 For now, see the L<Reindeer> docs for information about what meta extensions
 are automatically applied.
 
+=for Pod::Coverage     init_meta
+
 =head1 SEE ALSO
 
-L<Reindeer>, L<Moose::Role>
+Please see those modules/websites for more information related to this module.
+
+=over 4
+
+=item *
+
+L<Reindeer|Reindeer>
+
+=item *
+
+L<Moose::Role>
+
+=back
+
+=head1 SOURCE
+
+The development version is on github at L<http://github.com/RsrchBoy/reindeer>
+and may be cloned from L<git://github.com/RsrchBoy/reindeer.git>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+https://github.com/RsrchBoy/reindeer/issues
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
 
 =head1 AUTHOR
 
